@@ -13,7 +13,7 @@ import os
 import ssl
 
 class IFBroker(object):
-    def __init__(self, binding, manager=None):
+    def __init__(self, binding='*', manager=None):
         self.address = IFAddress.parseAddress(binding)
         socket = zmq.Context().socket(zmq.ROUTER)
         socket.bind(f'{self.address[0]}://{self.address[1]}:{self.address[2]}')
