@@ -10,11 +10,12 @@ import threading
 import asyncio
 import logging
 
+
 class IFWorker(object):
     def __init__(self, endpoint, serviceName=None, serviceObject=None, interfaces=[], blocking=True, timeout=None, force=False):
         self.address = IFAddress.parseAddress(endpoint)
         self.socket = zmq.Context().socket(zmq.DEALER)
-        self.__stream = ZMQStream(self.socket, IFLoop.INSTANCE)
+        self.__stream = ZMQStream(self.socket, IFLoop.getInstance())
         self.__stream.on_recv(self.__onMessage)
         self.__stream.socket.setsockopt(zmq.LINGER, 0)
         self.__stream.connect(f'{self.address[0]}://{self.address[1]}:{self.address[2]}')
@@ -44,7 +45,7 @@ class IFWorker(object):
             message = Message(msg)
             invocation = message.getInvocation()
             if invocation.isRequest():
-                IFLoop.INSTANCE.add_callback(self.__onRequest, message)
+                IFLoop.getInstance().add_callback(self.__onRequest, message)
             elif invocation.isResponse():
                 self.__onResponse(message)
         except BaseException as e:
@@ -110,7 +111,7 @@ class IFWorker(object):
 
     @classmethod
     def start(cls):
-        IFLoop.INSTANCE.start()
+        IFLoop.getInstance().start()
 
     def __getattr__(self, item):
         return InvokeTarget(self, item)
@@ -306,6 +307,7 @@ class InvokeFuture:
             self.__onComplete()
         self.__awaitSemaphore.release()
 
+
 if __name__ == '__main__':
     pass
 
@@ -319,4 +321,3 @@ if __name__ == '__main__':
     # # print(worker.HMC7044EvalAlice.checkChannel(1))
     # IFLoop.join()
 
-    
\ No newline at end of file
